==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/uk_UA.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk_UA" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Виберіть один або декілька пристроїв</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Перемикнутися на режим вікна</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Перемикнутися на повний екран</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Зворотній відлік</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Виберіть один або декілька пристроїв</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Запис не почато, бракує вільного місця на диску.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Досягнуто ліміту вільного місця на диску. </translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Ліміт вільного місця на диску</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Мегабайт</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Запис зупинено, бракує вільного місця на диску. </translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Весь екран</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Вікно</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Файлового менеджера не знайдено.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Будь ласка встановіть файловий менеджер.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>Знайдена сесія стільниці Wayland</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>На цю мить Wayland не підтримується. Запис покаже чорний екран. Будь ласка вийдіть та запустіть сесію X11</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Джерельний код</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переклади</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Зробити внесок</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Знайдена сесія стільниці Wayland</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Відкрити файл</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Діалогове вікно</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Показати горизонтально</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Показати вертикально</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Відобразити</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сірий</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>У відтінках сірого</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Прибрати рамку вікна</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Налаштування камери</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Збільшення</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Зворотній відлік</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Розмір відеофайлу: </translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Вільне місце на диску: </translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Час запису:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Кадри</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Відеокодек</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Аудіокодек</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Якість</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Не записувати курсор миші</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Година</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Хвилина</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Запустити таймер</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Зупинити запис через</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Години</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Хвилини</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Секунди</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Зберегти в теку</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Ліміт вільного місця на диску</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Показати значок на панелі</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Зачекати секунд перед початком запису</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Перевірити оновлення</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Доступний</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Недоступний</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Програти</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Папка</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Відобразити</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сірий</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Відправити скаргу</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Відтворити останній запис</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Згортати вікно при початку запису</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Запускати згорнутим</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Показати горизонтально</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Показати вертикально</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>У відтінках сірого</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Прибрати рамку вікна</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Зробити внесок</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Скинути усі налаштування при наступному старті</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Авторські права та ліцензія на зображення</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Мегабайт</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Скрінкаст</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Програвач</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Лог</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Авторські права та ліцензія на зображення</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Програти</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Відкрити файл</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Весь екран</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Попередній кадр</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Наступний кадр</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Без звуку</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Перемістити меню</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/uk_UA.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk_UA">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Виберіть один або декілька пристроїв</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Перемикнутися на режим вікна</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Перемикнутися на повний екран</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Виберіть один або декілька пристроїв</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Файлового менеджера не знайдено.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Будь ласка встановіть файловий менеджер.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Попередження</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Запис не почато, бракує вільного місця на диску.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Досягнуто ліміту вільного місця на диску. </translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Ліміт вільного місця на диску</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Мегабайт</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Запис зупинено, бракує вільного місця на диску. </translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Весь екран</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Вікно</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Файлового менеджера не знайдено.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Будь ласка встановіть файловий менеджер.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Джерельний код</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переклади</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Зробити внесок</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Виберіть один або декілька пристроїв</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Збільшення</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Діалогове вікно</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Показати горизонтально</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Показати вертикально</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Відобразити</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сірий</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>У відтінках сірого</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Прибрати рамку вікна</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Налаштування камери</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Довільна область</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Збільшення</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Зворотній відлік</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Розмір відеофайлу: </translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Вільне місце на диску: </translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Інформація</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Час запису:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Кадри</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Відеокодек</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Аудіокодек</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Якість</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Не записувати курсор миші</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Година</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Хвилина</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Запустити таймер</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Зупинити запис через</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Години</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Хвилини</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Секунди</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Зберегти в теку</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Ліміт вільного місця на диску</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Показати значок на панелі</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Зачекати секунд перед початком запису</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Перевірити оновлення</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Допомога</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Доступний</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Недоступний</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Почати</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продовжити</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Програти</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Папка</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Відобразити</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Сірий</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Відправити скаргу</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Відтворити останній запис</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Відкрити теку</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Згортати вікно при початку запису</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Запускати згорнутим</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Показати горизонтально</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Показати вертикально</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>У відтінках сірого</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Прибрати рамку вікна</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Зробити внесок</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Скинути усі налаштування при наступному старті</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Авторські права та ліцензія на зображення</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Мегабайт</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Скрінкаст</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Програвач</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Лог</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Авторські права та ліцензія на зображення</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Програти</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Відкрити файл</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Весь екран</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Попередній кадр</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Наступний кадр</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Без звуку</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Перемістити меню</translation>
    </message>
</context>
</TS>
